==> moserial-1.0.8.tar.bz2: moserial-1.0.8/src/ReceiveChooserDialog.h <==

#ifndef __SRC_RECEIVECHOOSERDIALOG_H__
#define __SRC_RECEIVECHOOSERDIALOG_H__

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS


#define MOSERIAL_TYPE_RECEIVE_CHOOSER_DIALOG (moserial_receive_chooser_dialog_get_type ())
#define MOSERIAL_RECEIVE_CHOOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MOSERIAL_TYPE_RECEIVE_CHOOSER_DIALOG, moserialReceiveChooserDialog))
#define MOSERIAL_RECEIVE_CHOOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MOSERIAL_TYPE_RECEIVE_CHOOSER_DIALOG, moserialReceiveChooserDialogClass))
#define MOSERIAL_IS_RECEIVE_CHOOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MOSERIAL_TYPE_RECEIVE_CHOOSER_DIALOG))
#define MOSERIAL_IS_RECEIVE_CHOOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MOSERIAL_TYPE_RECEIVE_CHOOSER_DIALOG))
#define MOSERIAL_RECEIVE_CHOOSER_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MOSERIAL_TYPE_RECEIVE_CHOOSER_DIALOG, moserialReceiveChooserDialogClass))

typedef struct _moserialReceiveChooserDialog moserialReceiveChooserDialog;
typedef struct _moserialReceiveChooserDialogClass moserialReceiveChooserDialogClass;
typedef struct _moserialReceiveChooserDialogPrivate moserialReceiveChooserDialogPrivate;

struct _moserialReceiveChooserDialog {
	GObject parent_instance;
	moserialReceiveChooserDialogPrivate * priv;
	GtkComboBox* protocolCombo;
	char* path;
};

struct _moserialReceiveChooserDialogClass {
	GObjectClass parent_class;
};


moserialReceiveChooserDialog* moserial_receive_chooser_dialog_construct (GType object_type, GtkBuilder* builder);
moserialReceiveChooserDialog* moserial_receive_chooser_dialog_new (GtkBuilder* builder);
void moserial_receive_chooser_dialog_show (moserialReceiveChooserDialog* self, const char* folder);
gboolean moserial_receive_chooser_dialog_hide (moserialReceiveChooserDialog* self, GtkWidget* w);
GtkBuilder* moserial_receive_chooser_dialog_get_builder (moserialReceiveChooserDialog* self);
GType moserial_receive_chooser_dialog_get_type (void);


G_END_DECLS

#endif

==> moserial-2.27.5.tar.bz2: moserial-2.27.5/src/ReceiveChooserDialog.h <==

#ifndef __SRC_RECEIVECHOOSERDIALOG_H__
#define __SRC_RECEIVECHOOSERDIALOG_H__

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS


#define MOSERIAL_TYPE_RECEIVE_CHOOSER_DIALOG (moserial_receive_chooser_dialog_get_type ())
#define MOSERIAL_RECEIVE_CHOOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MOSERIAL_TYPE_RECEIVE_CHOOSER_DIALOG, moserialReceiveChooserDialog))
#define MOSERIAL_RECEIVE_CHOOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MOSERIAL_TYPE_RECEIVE_CHOOSER_DIALOG, moserialReceiveChooserDialogClass))
#define MOSERIAL_IS_RECEIVE_CHOOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MOSERIAL_TYPE_RECEIVE_CHOOSER_DIALOG))
#define MOSERIAL_IS_RECEIVE_CHOOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MOSERIAL_TYPE_RECEIVE_CHOOSER_DIALOG))
#define MOSERIAL_RECEIVE_CHOOSER_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MOSERIAL_TYPE_RECEIVE_CHOOSER_DIALOG, moserialReceiveChooserDialogClass))

typedef struct _moserialReceiveChooserDialog moserialReceiveChooserDialog;
typedef struct _moserialReceiveChooserDialogClass moserialReceiveChooserDialogClass;
typedef struct _moserialReceiveChooserDialogPrivate moserialReceiveChooserDialogPrivate;

struct _moserialReceiveChooserDialog {
	GObject parent_instance;
	moserialReceiveChooserDialogPrivate * priv;
	GtkComboBox* protocolCombo;
	char* path;
};

struct _moserialReceiveChooserDialogClass {
	GObjectClass parent_class;
};


moserialReceiveChooserDialog* moserial_receive_chooser_dialog_construct (GType object_type, GtkBuilder* builder);
moserialReceiveChooserDialog* moserial_receive_chooser_dialog_new (GtkBuilder* builder);
void moserial_receive_chooser_dialog_show (moserialReceiveChooserDialog* self, const char* folder);
gboolean moserial_receive_chooser_dialog_hide (moserialReceiveChooserDialog* self);
GtkBuilder* moserial_receive_chooser_dialog_get_builder (moserialReceiveChooserDialog* self);
GType moserial_receive_chooser_dialog_get_type (void);


G_END_DECLS

#endif
